@@ -60,7 +60,6 @@ Folder::Folder(const FolderDefinition &definition,
     , _consecutiveFollowUpSyncs(0)
     , _journal(_definition.absoluteJournalPath())
     , _fileLog(new SyncRunFileLog)
-    , _saveBackwardsCompatible(false)
 {
     _timeSinceLastSyncStart.start();
     _timeSinceLastSyncDone.start();
@@ -534,6 +533,15 @@ void Folder::downloadVirtualFile(const QString &_relativepath)
     slotScheduleThisFolder();
 }
 
+
+void Folder::setUseVirtualFiles(bool enabled)
+{
+    _definition.useVirtualFiles = enabled;
+    if (enabled)
+        _saveInFoldersWithPlaceholders = true;
+    saveToSettings();
+}
+
 void Folder::saveToSettings() const
 {
     // Remove first to make sure we don't get duplicates
@@ -551,9 +559,9 @@ void Folder::saveToSettings() const
         }
     }
 
-    if (_definition.useVirtualFiles) {
-        // If virtual files are enabled, save the folder to a group
-        // that will not be read by older (<2.5.0) clients.
+    if (_definition.useVirtualFiles || _saveInFoldersWithPlaceholders) {
+        // If virtual files are enabled or even were enabled at some point,
+        // save the folder to a group that will not be read by older (<2.5.0) clients.
         // The name is from when virtual files were called placeholders.
         settingsGroup = QStringLiteral("FoldersWithPlaceholders");
     } else if (_saveBackwardsCompatible || oneAccountOnly) {
@@ -664,7 +672,7 @@ void Folder::startSync(const QStringList &pathList)
     _syncResult.setStatus(SyncResult::SyncPrepare);
     emit syncStateChange();
 
-    qCInfo(lcFolder) << "*** Start syncing " << remoteUrl().toString() << " - client version"
+    qCInfo(lcFolder) << "*** Start syncing " << remoteUrl().toString() << " -" << APPLICATION_NAME << "client version"
                      << qPrintable(Theme::instance()->version());
 
     _fileLog->start(path());
@@ -1134,7 +1142,7 @@ void FolderDefinition::save(QSettings &settings, const FolderDefinition &folder)
     settings.setValue(QLatin1String("paused"), folder.paused);
     settings.setValue(QLatin1String("ignoreHiddenFiles"), folder.ignoreHiddenFiles);
     settings.setValue(QLatin1String("usePlaceholders"), folder.useVirtualFiles);
-    settings.setValue(QLatin1String(versionC), maxSettingsVersion());
+    settings.setValue(QLatin1String(versionC), 1);
 
     // Happens only on Windows when the explorer integration is enabled.
     if (!folder.navigationPaneClsid.isNull())
