@@ -16,6 +16,7 @@
 #include "ui_generalsettings.h"
 
 #include "theme.h"
+#include "version.h"
 #include "configfile.h"
 #include "application.h"
 #include "configfile.h"
@@ -51,9 +52,14 @@ GeneralSettings::GeneralSettings(QWidget *parent)
         this, &GeneralSettings::slotToggleOptionalDesktopNotifications);
     connect(_ui->showInExplorerNavigationPaneCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::slotShowInExplorerNavigationPane);
 
-    _ui->autostartCheckBox->setChecked(Utility::hasLaunchOnStartup(Theme::instance()->appName()));
-    connect(_ui->autostartCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::slotToggleLaunchOnStartup);
-
+    if(Utility::hasSystemLaunchOnStartup(Theme::instance()->appName())) {
+        _ui->autostartCheckBox->setChecked(true);
+        _ui->autostartCheckBox->setDisabled(true);
+        _ui->autostartCheckBox->setToolTip(tr("You cannot disable autostart because system-wide autostart is enabled."));
+    } else {
+        _ui->autostartCheckBox->setChecked(Utility::hasLaunchOnStartup(Theme::instance()->appName()));
+        connect(_ui->autostartCheckBox, &QAbstractButton::toggled, this, &GeneralSettings::slotToggleLaunchOnStartup);
+    }
     loadMiscSettings();
     slotUpdateInfo();
 
@@ -96,12 +102,20 @@ GeneralSettings::GeneralSettings(QWidget *parent)
     if (theme->appName() != QLatin1String("ownCloud") && theme->appName() != QLatin1String("testpilotcloud") ) {
 #ifdef Q_OS_MAC
         // Because we don't have any statusString from the SparkleUpdater anyway we can hide the whole thing
-        _ui->updatesGroupBox->hide();
+        _ui->updaterWidget->hide();
 #else
         _ui->updateChannelLabel->hide();
         _ui->updateChannel->hide();
 #endif
     }
+
+    _ui->versionLabel->setText(QStringLiteral("<a href='%1'>%1</a>").arg(MIRALL_VERSION_STRING));
+    QObject::connect(_ui->versionLabel, &QLabel::linkActivated, this, &GeneralSettings::showAbout);
+
+    if (!theme->aboutShowCopyright()) {
+        _ui->copyrightLabelDotBefore->hide();
+        _ui->copyrightLabel->hide();
+    }
 }
 
 GeneralSettings::~GeneralSettings()
@@ -134,7 +148,7 @@ void GeneralSettings::slotUpdateInfo()
 {
     if (ConfigFile().skipUpdateCheck() || !Updater::instance()) {
         // updater disabled on compile
-        _ui->updatesGroupBox->setVisible(false);
+        _ui->updaterWidget->setVisible(false);
         return;
     }
 
